module Doct
  class Template < Array
    attr_reader :format
    FORMATS = {}

    def self.register_format(format, *extensions)
      extensions.each {|ext| FORMATS[ext] = format}
    end
    def initialize(filename, format = nil)
      format ||= File.extname(filename)[1..-1].to_s.downcase
      raise "Unrecognized format '#{format}'" unless FORMATS[format]
      @format = FORMATS[format].new(filename)
    end
    def placeholders
      @format.placeholders.map(&:to_sym)
    end
    def save_as filename
      open(filename, "wb") { |io| io << render }
    end
    def render
      @format.render self
    end
  end
end

Dir["#{File.dirname(__FILE__)}/formats/*.rb"].each {|file| require file}
